==> knative-model-4.6.3-sources.jar: io/fabric8/knative/serving/v1alpha1/RouteSpecFluent.java <==
package io.fabric8.knative.serving.v1alpha1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface RouteSpecFluent<A extends io.fabric8.knative.serving.v1alpha1.RouteSpecFluent<A>> extends Fluent<A>{


    public Long getGeneration();
    public A withGeneration(Long generation);
    public Boolean hasGeneration();
    public A addToTraffic(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public A setToTraffic(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public A addToTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... items);
    public A addAllToTraffic(Collection<io.fabric8.knative.serving.v1alpha1.TrafficTarget> items);
    public A removeFromTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... items);
    public A removeAllFromTraffic(Collection<io.fabric8.knative.serving.v1alpha1.TrafficTarget> items);
    
/**
 * This method has been deprecated, please use method buildTraffic instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> getTraffic();
    public List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> buildTraffic();
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildTraffic(int index);
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildFirstTraffic();
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildLastTraffic();
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);
    public Boolean hasMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);
    public A withTraffic(List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> traffic);
    public A withTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... traffic);
    public Boolean hasTraffic();
    public RouteSpecFluent.TrafficNested<A> addNewTraffic();
    public RouteSpecFluent.TrafficNested<A> addNewTrafficLike(io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public RouteSpecFluent.TrafficNested<A> setNewTrafficLike(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public RouteSpecFluent.TrafficNested<A> editTraffic(int index);
    public RouteSpecFluent.TrafficNested<A> editFirstTraffic();
    public RouteSpecFluent.TrafficNested<A> editLastTraffic();
    public RouteSpecFluent.TrafficNested<A> editMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);

    public interface TrafficNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.TrafficTargetFluent<RouteSpecFluent.TrafficNested<N>>{

        
    public N and();    public N endTraffic();
}


}

==> knative-model-4.7.2-sources.jar: io/fabric8/knative/serving/v1alpha1/RouteSpecFluent.java <==
package io.fabric8.knative.serving.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.fabric8.kubernetes.api.builder.Predicate;
import java.lang.Deprecated;
import java.lang.Long;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface RouteSpecFluent<A extends io.fabric8.knative.serving.v1alpha1.RouteSpecFluent<A>> extends Fluent<A>{


    public Long getGeneration();
    public A withGeneration(Long generation);
    public Boolean hasGeneration();
    public A addToTraffic(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public A setToTraffic(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public A addToTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... items);
    public A addAllToTraffic(Collection<io.fabric8.knative.serving.v1alpha1.TrafficTarget> items);
    public A removeFromTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... items);
    public A removeAllFromTraffic(Collection<io.fabric8.knative.serving.v1alpha1.TrafficTarget> items);
    public A removeMatchingFromTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildTraffic instead.
 * @return The buildable object.
 */
@Deprecated public List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> getTraffic();
    public List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> buildTraffic();
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildTraffic(int index);
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildFirstTraffic();
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildLastTraffic();
    public io.fabric8.knative.serving.v1alpha1.TrafficTarget buildMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);
    public Boolean hasMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);
    public A withTraffic(List<io.fabric8.knative.serving.v1alpha1.TrafficTarget> traffic);
    public A withTraffic(io.fabric8.knative.serving.v1alpha1.TrafficTarget... traffic);
    public Boolean hasTraffic();
    public RouteSpecFluent.TrafficNested<A> addNewTraffic();
    public RouteSpecFluent.TrafficNested<A> addNewTrafficLike(io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public RouteSpecFluent.TrafficNested<A> setNewTrafficLike(int index,io.fabric8.knative.serving.v1alpha1.TrafficTarget item);
    public RouteSpecFluent.TrafficNested<A> editTraffic(int index);
    public RouteSpecFluent.TrafficNested<A> editFirstTraffic();
    public RouteSpecFluent.TrafficNested<A> editLastTraffic();
    public RouteSpecFluent.TrafficNested<A> editMatchingTraffic(io.fabric8.kubernetes.api.builder.Predicate<io.fabric8.knative.serving.v1alpha1.TrafficTargetBuilder> predicate);

    public interface TrafficNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.knative.serving.v1alpha1.TrafficTargetFluent<RouteSpecFluent.TrafficNested<N>>{

        
    public N and();    public N endTraffic();
}


}
